# CreateModelJobStatusDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**model_job_id** | **str** |  | 
**project_id** | **str** |  | 
**source** | **str** |  | [optional] 
**step** | **str** |  | 
**message** | **str** |  | [optional] 
**type** | **str** |  | [optional] 
**order** | **float** |  | [optional] 
**progress** | **float** |  | [optional] 
**metadata** | **object** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

